*******************************************************************************************************************************
**** Project: Exeter Q-Step Workshop: Presenting regression results
**** Author: Nils-Christian Bormann
**** Task: Write example code for exporting regression results as tables and plots
**** Version:
  *1* 21 Mar 2016: Export regression tables (estout) and plot predicted values
 

*******************************************************************************************************************************
**** Header
findit estout
set more off
cd "/home/ncb/Documents/Academics/Teaching/R-GIS Introduction Workshop" // working directory on personal computer
*capture cd "" // working directory on lab computer


*******************************************************************************************************************************
**** Data
use "data/FL03.dta", clear
summ * // summary statistics for all variables

xtset ccode year // prepare data for fixed and random effects models

** Variable labels
label var polity2l "Polity Score"
label var lgdpenl1 "GDP p.c. (log)"
label var lpopl1  "Population (log)"
label var ethfrac "Ethnic Fractionalization"
label var Oil "Oil"

*******************************************************************************************************************************
**** Analysis
eststo clear 

** Model 1: Regress population, ethnic fractionalization, and oil on democracy (ordinary least squares)
eststo: reg polity2l lpopl1 ethfrac Oil, vce(cluster ccode)
// the argument after the comma specifies that standard errors are clustered on the country level

** Model 2: Regress gdp, population, ethnic fractionalization, and oil on democracy (ordinary least squares)
eststo: reg polity2l lgdpenl1 lpopl1 ethfrac Oil, vce(cluster ccode)

** Model 3: Regress gdp, population, ethnic fractionalization, and oil on democracy + country and year fixed effects (ordinary least squares)
eststo: xtreg polity2l lgdpenl1 lpopl1 Oil, fe vce(cluster ccode)

** Model 4: Regress gdp, population, ethnic fractionalization, and oil on democracy (ordinary least squares)
reg polity2l c.lgdpenl1##c.Oil lpopl1 ethfrac, vce(cluster ccode)

** Model 5: Regress gdp, population, ethnic fractionalization and oil on democracy + random effects (linear hierarchical model)
xtreg polity2l c.lgdpenl1##c.Oil lpopl1 ethfrac, re vce(cluster ccode)

** Table 1
esttab using tables/table1.rtf, se label replace ///
	title("Explaining Levels of Democracy (OLS), 1945-1999.") 

** Add Model 4 to the table
  * reorder variables so that the table indicates, GDP first, oil*gdp second, and oil third with population and ethnic fractionalizaton afterwards
  * pay attention to the variable labels
  * hint search http://repec.org/bocode/e/estout/esttab.html for interaction

eststo clear 

** Model 1: Regress population, ethnic fractionalization, and oil on democracy (ordinary least squares)
eststo: reg polity2l lpopl1 ethfrac Oil, vce(cluster ccode)
// the argument after the comma specifies that standard errors are clustered on the country level

** Model 2: Regress gdp, population, ethnic fractionalization, and oil on democracy (ordinary least squares)
eststo: reg polity2l lgdpenl1 lpopl1 ethfrac Oil, vce(cluster ccode)

** Model 3: Regress gdp, population, ethnic fractionalization, and oil on democracy + country and year fixed effects (ordinary least squares)
eststo: xtreg polity2l lgdpenl1 lpopl1 Oil, fe vce(cluster ccode)

** Model 4: Regress gdp, population, ethnic fractionalization, and oil on democracy (ordinary least squares)
eststo: reg polity2l c.lgdpenl1##c.Oil lpopl1 ethfrac, vce(cluster ccode)
  
 esttab using "tables/table2.rtf", se label replace ///
	title("Explaining Levels of Democracy (OLS), 1945-1999.") ///
	 nobaselevels interaction(" X ")
	 

*******************************************************************************************************************************
**** Substantive effects and plots
	 
** Model 2: Regress gdp, population, ethnic fractionalization, and oil on democracy (ordinary least squares)
reg polity2l lgdpenl1 lpopl1 ethfrac Oil, vce(cluster ccode)
	 
margins, at(Oil=(0(1)1)) atmeans
marginsplot, ytitle("Predicted Polity Score") xtitle("Oil") title("") ///
	scheme(s2mono)
marginsplot, ytitle("Predicted Polity Score") xtitle("Oil") title("") ///
	scheme(s2mono) recast(dropline)


** Model 4: Regress gdp, population, ethnic fractionalization, and oil on democracy (ordinary least squares)
reg polity2l c.lgdpenl1##c.Oil lpopl1 ethfrac, vce(cluster ccode)	

summ(lgdpenl1)
margins, at(lgdpenl1=(4(0.1)11) Oil=(0(1)1)) atmeans
marginsplot, ytitle("Predicted Polity Score") xtitle("GDP p.c.") title("") ///
	scheme(s2mono) recast(line) recastci(rarea)
